ConsentSdkPluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- ConsentSdkPluginPlatform
- Implementers
Constructors
- ConsentSdkPluginPlatform()
- Constructs a ConsentSdkPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
presentConsentBanner(
) → void -
presentPreferenceCenter(
) → void -
setupSDK(
Map options) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ConsentSdkPluginPlatform
-
The default instance of ConsentSdkPluginPlatform to use.
getter/setter pair